==> v6.0.tar.gz: uhr/uhr-en.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_it_is": {1:[1,2,4,5]},
	"_half": {4:[1,2,3,4]},
	"_to": {4:[10,11]},
	"_past": {5:[1,2,3,4]},
	"_o_clock": {10:[6,7,8,9,10,11]},
	"_5": {3:[7,8,9,10]},
	"_10": {4:[6,7,8]},
	"_15": {2:[1,3,4,5,6,7,8,9]},
	"_20": {3:[1,2,3,4,5,6]},
	"_25": {3:[1,2,3,4,5,6,7,8,9,10]}
};
var layout = {
	"version": 2,
	"language": 'English',
	/*
		[l('I', 'on'), l('T', 'on'),l('L'),l('I', 'on'),l('S', 'on'),l('B'),l('F'),l('A'),l('M'),l('P'),l('M')],
		[m('A', 15, 45), l('C'),m('Q', 15, 45),m('U', 15, 45),m('A', 15, 45),m('R', 15, 45),m('T', 15, 45),m('E', 15, 45),m('R', 15, 45),l('D'),l('C')],
		[m('T', 20, 25, 35, 40), m('W', 20, 25, 35, 40),m('E', 20, 25, 35, 40),m('N', 20, 25, 35, 40),m('T', 20, 25, 35, 40),m('Y', 20, 25, 35, 40),m('F', 5, 25, 35, 55),m('I', 5, 25, 35, 55),m('V', 5, 25, 35, 55),m('E', 5, 25, 35, 55),l('X')],
		[m('H', 30), m('A', 30),m('L', 30),m('F', 30),l('B'),m('T', 10, 50),m('E', 10, 50),m('N', 10, 50),l('F'),m('T', 35, 40, 45, 50, 55),m('O', 35, 40, 45, 50, 55)],
		[m('P', 5, 10, 15, 20, 25, 30),m('A', 5, 10, 15, 20, 25, 30),m('S', 5, 10, 15, 20, 25, 30),m('T', 5, 10, 15, 20, 25, 30),l('E'),l('R'),l('U'),h('N', 9),h('I', 9),h('N', 9),h('E', 9)],
		[h('O', 1), h('N', 1),h('E', 1),h('S', 6),h('I', 6),h('X', 6),h('T', 3),h('H', 3),h('R', 3),h('E', 3),h('E', 3)],
		[h('F', 4), h('O', 4),h('U', 4),h('R', 4),h('F', 5),h('I', 5),h('V', 5),h('E', 5),h('T', 2),h('W', 2),h('O', 2)],
		[h('E', 8), h('I', 8),h('G', 8),h('H', 8),h('T', 8),h('E', 11),h('L', 11),h('E', 11),h('V', 11),h('E', 11),h('N', 11)],
		[h('S', 7), h('E', 7),h('V', 7),h('E', 7),h('N', 7),h('T', 12),h('W', 12),h('E', 12),h('L', 12),h('V', 12),h('E', 12)],
		[h('T', 10), h('E', 10),h('N', 10),l('S'),l('E'),l('O', 'sharphour'),l('C', 'sharphour'),l('L', 'sharphour'),l('O', 'sharphour'),l('C', 'sharphour'),l('K', 'sharphour')]
	*/
	"letters": [
		'ITLISBFAMPM',
		'ACQUARTERDC',
		'TWENTYFIVEX',
		'HALFBTENFTO',
		'PASTERUNINE',
		'ONESIXTHREE',
		'FOURFIVETWO',
		'EIGHTELEVEN',
		'SEVENTWELVE',
		'TENSEOCLOCK'
		],
	"permanent": h._it_is,
	"minutes": {
		"0,1,2,3,4": h._o_clock,
		"5,6,7,8,9": [h._5, h._past],
		"10,11,12,13,14": [h._10, h._past],
		"15,16,17,18,19": [h._15, h._past],
		"20,21,22,23,24": [h._20, h._past],
		"25,26,27,28,29": [h._25, h._past],
		"30,31,32,33,34": [h._half, h._past],
		"35,36,37,38,39": [h._25, h._to],
		"40,41,42,43,44": [h._20, h._to],
		"45,46,47,48,49": [h._15, h._to],
		"50,51,52,53,54": [h._10, h._to],
		"55,56,57,58,59": [h._5, h._to]
	},
	"hours": {
		"1": {6:[1,2,3]},
		"2": {7:[9,10,11]},
		"3": {6:[7,8,9,10,11]},
		"4": {7:[1,2,3,4]},
		"5": {7:[5,6,7,8]},
		"6": {6:[4,5,6]},
		"7": {9:[1,2,3,4,5]},
		"8": {8:[1,2,3,4,5]},
		"9": {5:[8,9,10,11]},
		"10": {10:[1,2,3]},
		"11": {8:[6,7,8,9,10,11]},
		"12": {9:[6,7,8,9,10,11]}
	},
	"getHour": function(date) {
		var hour = date.getHours();
		if (date.getMinutes() >= 35) {
			return hour + 1;
		}
		return hour;
	}
};
window,_uhr.register('en', layout);

==> v6.2.tar.gz: uhr/uhr-en.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_it_is": {1:[1,2,4,5]},
	"_half": {4:[1,2,3,4]},
	"_to": {4:[10,11]},
	"_past": {5:[1,2,3,4]},
	"_o_clock": {10:[6,7,8,9,10,11]},
	"_5": {3:[7,8,9,10]},
	"_10": {4:[6,7,8]},
	"_15": {2:[1,3,4,5,6,7,8,9]},
	"_20": {3:[1,2,3,4,5,6]},
	"_25": {3:[1,2,3,4,5,6,7,8,9,10]}
};
var layout = {
	"version": 2,
	"language": 'English',
	"letters": [
		'ITLISBFAMPM',
		'ACQUARTERDC',
		'TWENTYFIVEX',
		'HALFBTENFTO',
		'PASTERUNINE',
		'ONESIXTHREE',
		'FOURFIVETWO',
		'EIGHTELEVEN',
		'SEVENTWELVE',
		'TENSEOCLOCK'
	],
	"permanent": h._it_is,
	"minutes": {
		"0,1,2,3,4": h._o_clock,
		"5,6,7,8,9": [h._5, h._past],
		"10,11,12,13,14": [h._10, h._past],
		"15,16,17,18,19": [h._15, h._past],
		"20,21,22,23,24": [h._20, h._past],
		"25,26,27,28,29": [h._25, h._past],
		"30,31,32,33,34": [h._half, h._past],
		"35,36,37,38,39": [h._25, h._to],
		"40,41,42,43,44": [h._20, h._to],
		"45,46,47,48,49": [h._15, h._to],
		"50,51,52,53,54": [h._10, h._to],
		"55,56,57,58,59": [h._5, h._to]
	},
	"hours": {
		"0,12": {9:[6,7,8,9,10,11]},
		"1,13": {6:[1,2,3]},
		"2,14": {7:[9,10,11]},
		"3,15": {6:[7,8,9,10,11]},
		"4,16": {7:[1,2,3,4]},
		"5,17": {7:[5,6,7,8]},
		"6,18": {6:[4,5,6]},
		"7,19": {9:[1,2,3,4,5]},
		"8,20": {8:[1,2,3,4,5]},
		"9,21": {5:[8,9,10,11]},
		"10,22": {10:[1,2,3]},
		"11,23": {8:[6,7,8,9,10,11]}
	},
	"getHour": function(date) {
		var hour = date.getHours();
		if (date.getMinutes() >= 35) {
			return hour + 1;
		}
		return hour;
	}
};
window,_uhr.register('en', layout);
